==> qt-creator-opensource-src-3.0.0.zip: qt-creator-opensource-src-3.0.0/src/plugins/qnx/bardescriptoreditorassetswidget.h <==
/**************************************************************************
**
** Copyright (C) 2013 BlackBerry Limited. All rights reserved.
**
** Contact: BlackBerry (qt@blackberry.com)
** Contact: KDAB (info@kdab.com)
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QNX_INTERNAL_BARDESCRIPTOREDITORASSETSWIDGET_H
#define QNX_INTERNAL_BARDESCRIPTOREDITORASSETSWIDGET_H

#include "bardescriptoreditorabstractpanelwidget.h"

QT_BEGIN_NAMESPACE
class QStandardItem;
class QStandardItemModel;
QT_END_NAMESPACE

namespace Qnx {
namespace Internal {

namespace Ui {
class BarDescriptorEditorAssetsWidget;
}

class BarDescriptorAsset;

class BarDescriptorEditorAssetsWidget : public BarDescriptorEditorAbstractPanelWidget
{
    Q_OBJECT

public:
    explicit BarDescriptorEditorAssetsWidget(QWidget *parent = 0);
    ~BarDescriptorEditorAssetsWidget();

    void clear();

    void addAsset(const BarDescriptorAsset &asset);
    QList<BarDescriptorAsset> assets() const;

    QStandardItemModel *assetsModel() const;

public slots:
    void addAsset(const QString &fullPath);
    void removeAsset(const QString &fullPath);

private slots:
    void addNewAsset();
    void removeSelectedAsset();
    void updateEntryCheckState(QStandardItem *item);

private:
    void connectAssetsModel();
    void disconnectAssetsModel();

    void addAssetInternal(const BarDescriptorAsset &asset);
    bool hasAsset(const BarDescriptorAsset &asset);

    Ui::BarDescriptorEditorAssetsWidget *m_ui;

    QStandardItemModel *m_assetsModel;
};


} // namespace Internal
} // namespace Qnx
#endif // QNX_INTERNAL_BARDESCRIPTOREDITORASSETSWIDGET_H

==> qt-creator-opensource-src-3.2.2.zip: qt-creator-opensource-src-3.2.2/src/plugins/qnx/bardescriptoreditorassetswidget.h <==
/**************************************************************************
**
** Copyright (C) 2014 BlackBerry Limited. All rights reserved.
**
** Contact: BlackBerry (qt@blackberry.com)
** Contact: KDAB (info@kdab.com)
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://www.qt.io/licensing.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QNX_INTERNAL_BARDESCRIPTOREDITORASSETSWIDGET_H
#define QNX_INTERNAL_BARDESCRIPTOREDITORASSETSWIDGET_H

#include "bardescriptoreditorabstractpanelwidget.h"

QT_BEGIN_NAMESPACE
class QStandardItem;
class QStandardItemModel;
QT_END_NAMESPACE

namespace Qnx {
namespace Internal {

namespace Ui { class BarDescriptorEditorAssetsWidget; }

class BarDescriptorAsset;

class BarDescriptorEditorAssetsWidget : public BarDescriptorEditorAbstractPanelWidget
{
    Q_OBJECT

public:
    explicit BarDescriptorEditorAssetsWidget(QWidget *parent = 0);
    ~BarDescriptorEditorAssetsWidget();

    QStandardItemModel *assetsModel() const;

public slots:
    void addAsset(const QString &fullPath);
    void removeAsset(const QString &fullPath);

protected:
    void updateWidgetValue(BarDescriptorDocument::Tag tag, const QVariant &value);
    void emitChanged(BarDescriptorDocument::Tag tag);

private slots:
    void addNewAsset();
    void removeSelectedAsset();
    void updateEntryCheckState(QStandardItem *item);

private:
    void clear();
    void addAsset(const BarDescriptorAsset &asset);
    bool hasAsset(const BarDescriptorAsset &asset);

    Ui::BarDescriptorEditorAssetsWidget *m_ui;

    QStandardItemModel *m_assetsModel;
};


} // namespace Internal
} // namespace Qnx
#endif // QNX_INTERNAL_BARDESCRIPTOREDITORASSETSWIDGET_H
